@@ -6,6 +6,7 @@ Created on 12 Sep 2020
 @author: semuadmin
 '''
 
+from threading import Thread
 from tkinter import Tk, Frame, N, S, E, W, PhotoImage, font
 
 from .about_dialog import AboutDialog
@@ -20,9 +21,9 @@ from .serial_handler import SerialHandler
 from .settings_frame import SettingsFrame
 from .skyview_frame import SkyviewFrame
 from .status_frame import StatusFrame
-from .strings import TITLE, INTROTXT, MENUHIDESE, MENUSHOWSE, \
-                                MENUHIDESB, MENUSHOWSB, MENUHIDECON, MENUSHOWCON, MENUHIDEMAP, \
-                                MENUSHOWMAP, MENUHIDESATS, MENUSHOWSATS, INTROTXTNOPORTS
+from .strings import TITLE, MENUHIDESE, MENUSHOWSE, \
+                    MENUHIDESB, MENUSHOWSB, MENUHIDECON, MENUSHOWCON, MENUHIDEMAP, \
+                    MENUSHOWMAP, MENUHIDESATS, MENUSHOWSATS, INTROTXTNOPORTS
 from .ubx_config_dialog import UBXConfigDialog
 from .nmea_handler import NMEAHandler
 from .ubx_handler import UBXHandler
@@ -62,6 +63,7 @@ class App(Frame):
         self.nmea_handler = NMEAHandler(self)
         self.ubx_handler = UBXHandler(self)
         self.dlg_ubxconfig = None
+        self._config_thread = None
 
         # Load web map api key if there is one
         self.api_key = self.file_handler.load_apikey()
@@ -86,6 +88,7 @@ class App(Frame):
         self.__master.grid_rowconfigure(2, weight=1)
         self._set_default_fonts()
 
+        self.menu = MenuBar(self)
         self.frm_status = StatusFrame(self, borderwidth=2, relief="groove")
         self.frm_banner = BannerFrame(self, borderwidth=2, relief="groove")
         self.frm_settings = SettingsFrame(self, borderwidth=2, relief="groove")
@@ -93,7 +96,6 @@ class App(Frame):
         self.frm_mapview = MapviewFrame(self, borderwidth=2, relief="groove")
         self.frm_satview = SkyviewFrame(self, borderwidth=2, relief="groove")
         self.frm_graphview = GraphviewFrame(self, borderwidth=2, relief="groove")
-        self.menu = MenuBar(self)
 
         self.__master.config(menu=self.menu)
 
@@ -112,9 +114,9 @@ class App(Frame):
 
         if self.frm_settings.get_settings()['noports']:
             self.set_status(INTROTXTNOPORTS, "red")
-        else:
-            self.set_status(INTROTXT, "blue")
-        # self.frm_settings._lbx_port.focus_set()
+#         else:
+#             self.set_status(INTROTXT, "blue")
+#         # self.frm_settings._lbx_port.focus_set()
 
     def _attach_events(self):
         '''
@@ -123,6 +125,7 @@ class App(Frame):
 
         self.__master.bind('<<ubx_read>>', self.serial_handler.on_read)
         self.__master.bind('<<ubx_readfile>>', self.serial_handler.on_read)
+        self.__master.bind('<<ubx_eof>>', self.serial_handler.on_eof)
         self.__master.bind_all("<Control-q>", self.exit)
 
     def _set_default_fonts(self):
@@ -239,16 +242,27 @@ class App(Frame):
 
     def ubxconfig(self):
         '''
-        Open UBX Config dialog
-        Update idle tasks and flush input buffer first
-        to minimise blocking on startup during heavy
-        traffic
+        Start UBX Config dialog thread
+        '''
+
+        self._config_thread = Thread(target=self._ubxconfig_thread, daemon=False)
+        self._config_thread.start()
+
+    def _ubxconfig_thread(self):
+        '''
+        THREADED PROCESS UBX Configuration Dialog
         '''
 
-        self.__master.update_idletasks()
-        self.serial_handler.flush()
         self.dlg_ubxconfig = UBXConfigDialog(self)
 
+    def stop_config_thread(self):
+        '''
+        Stop UBX Configuration dialog thread.
+        '''
+
+        if self._config_thread is not None:
+            self._config_thread.join()
+
     def get_master(self):
         '''
         Returns application master (Tk)
@@ -262,6 +276,8 @@ class App(Frame):
         '''
 
         self.serial_handler.stop_read_thread()
+        self.serial_handler.stop_readfile_thread()
+        self.stop_config_thread()
         self.serial_handler.disconnect()
         self.__master.destroy()
 
